## 4.2.5.20241221 (2024-12-21)

Update to mypy 1.14 (#13272)

## 4.2.5.20241002 (2024-10-02)

[stubsabot] Bump reportlab to 4.2.5 (#12719)

Release: https://pypi.org/pypi/reportlab/4.2.5
Homepage: https://www.reportlab.com/
Repository: https://github.com/MrBitBucket/reportlab-mirror
Typeshed stubs: https://github.com/python/typeshed/tree/main/stubs/reportlab

If stubtest fails for this PR:
- Leave this PR open (as a reminder, and to prevent stubsabot from opening another PR)
- Fix stubtest failures in another PR, then close this PR

Note that you will need to close and re-open the PR in order to trigger CI

Co-authored-by: stubsabot <>

## 4.2.4.20240930 (2024-09-30)

Bump reportlab to 4.2.4 (#12701)

## 4.2.2.20240819 (2024-08-19)

Forbid extremely long line lengths in non-autogenerated stubs (#12537)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>

## 4.2.2.20240806 (2024-08-06)

Bump mypy to 1.11.1 (#12463)

## 4.2.2.20240701 (2024-07-01)

Bump reportlab to 4.2.2 (#12227)

## 4.2.0.20240627 (2024-06-27)

Add upstream_repository for reportlab (#12223)

This was found at https://docs.reportlab.com/releases/#reportlab-build-process

Pin reportlab to version 4.2.0 (#12220)

Part of #12213

## 4.2.0.20240530 (2024-05-30)

reportlab: Add some basic type hints for graphics rendering API (#12051)

## 4.2.0.20240525 (2024-05-25)

Adds stubs for reportlab (#12013)

